@@ -192,11 +192,6 @@ int64_t PipeWireRecordProduce::framePts(const std::optional<std::chrono::nanosec
 
 void PipeWireRecordProduce::cleanup()
 {
-    if (m_encoder) {
-        // Clear the queue of encoded packets.
-        m_encoder->receivePacket();
-    }
-
     if (m_avFormatContext) {
         if (auto result = av_write_trailer(m_avFormatContext); result < 0) {
             qCWarning(PIPEWIRERECORD_LOGGING) << "Could not write trailer";
